@@ -1,7 +1,7 @@
 import click
 
 import montecarlodata.settings as settings
-from montecarlodata.collector.commands import collector
+from montecarlodata.collector.commands import collectors
 from montecarlodata.common.user import UserService
 from montecarlodata.config import ConfigManager
 from montecarlodata.discovery.commands import discovery
@@ -34,7 +34,7 @@ def entry_point(ctx, profile, config_path):
 @click.option('--config-path', required=False, help='Specify path where to look for config file.',
               default=settings.DEFAULT_CONFIG_PATH, type=click.Path(dir_okay=True))
 @click.option('--mcd-id', prompt='Key ID', help='Monte Carlo token user ID.')
-@click.password_option('--mcd-token', prompt='Secret', help='Monte Carlo token value.')
+@click.option('--mcd-token', prompt='Secret', help='Monte Carlo token value.', hide_input=True)
 @click.option('--aws-profile', prompt='AWS profile name',
               help='AWS named profile with access to the DC stack and resources (e.g. CloudFormation and S3).',
               default='')
@@ -62,7 +62,7 @@ def validate(ctx):
 entry_point.add_command(integrations)
 entry_point.add_command(configure)
 entry_point.add_command(validate)
-entry_point.add_command(collector)
+entry_point.add_command(collectors)
 entry_point.add_command(discovery)
 entry_point.add_command(monitors)
 
