@@ -3,51 +3,103 @@ from typing import Optional, Dict, List
 from urllib import parse
 
 import click
+from tabulate import tabulate
 
-from montecarlodata.collector.fields import EXPECTED_GENERATE_TEMPLATE_GQL_RESPONSE_FIELD, DEFAULT_COLLECTION_REGION
+from montecarlodata.collector.fields import EXPECTED_GENERATE_TEMPLATE_GQL_RESPONSE_FIELD, DEFAULT_COLLECTION_REGION, \
+    EXPECTED_ADD_DC_RESPONSE_FIELD, ADD_DC_PROMPT_VERBIAGE, ADD_DC_REGION_PROMPT_VERBIAGE
+from montecarlodata.common.user import UserService
 from montecarlodata.config import Config
-from montecarlodata.errors import manage_errors, complain_and_abort
-from montecarlodata.queries.collector import GENERATE_COLLECTOR_TEMPLATE
+from montecarlodata.errors import manage_errors, complain_and_abort, prompt_connection
+from montecarlodata.queries.collector import GENERATE_COLLECTOR_TEMPLATE, ADD_COLLECTOR_RECORD
 from montecarlodata.utils import GqlWrapper, AwsClientWrapper
 
 
 class CollectorManagementService:
+    _DEFAULT_COLLECTOR_VAL = '-'
+    _LIST_COLLECTOR_HEADERS = ['AWS Stack ARN', 'ID', 'Version', 'Last updated', 'Active']
+
     def __init__(self, config: Config, request_wrapper: Optional[GqlWrapper] = None,
                  aws_wrapper: Optional[AwsClientWrapper] = None, aws_profile_override: Optional[str] = None,
-                 aws_region_override: Optional[str] = None):
+                 aws_region_override: Optional[str] = None, user_service: Optional[UserService] = None):
         self._abort_on_error = True
         self._collector_region = aws_region_override or config.aws_region or DEFAULT_COLLECTION_REGION
 
         self._request_wrapper = request_wrapper or GqlWrapper(mcd_id=config.mcd_id, mcd_token=config.mcd_token)
         self._aws_wrapper = aws_wrapper or AwsClientWrapper(profile_name=aws_profile_override or config.aws_profile,
                                                             region_name=self._collector_region)
+        self._user_service = user_service or UserService(request_wrapper=self._request_wrapper, config=config)
 
     @manage_errors
-    def echo_template(self) -> None:
+    def echo_template(self, **kwargs) -> None:
         """
         Echos the most recent template for this account
         """
-        click.echo(self._get_template_url_from_launch(self._get_template_launch_url()))
+        click.echo(self._get_template_url_from_launch(self._get_template_launch_url(**kwargs)))
 
     @manage_errors
-    def launch_quick_create_link(self, dry: Optional[bool] = True) -> None:
+    def echo_collectors(self, headers: Optional[str] = 'firstrow', table_format: Optional[str] = 'fancy_grid',
+                        active_only: Optional[bool] = False) -> None:
+        """
+        Echo collectors in a fancy grid.
+        """
+        table = [self._LIST_COLLECTOR_HEADERS]
+        for collector in self._user_service.collectors or []:
+            if active_only and not collector.get('active'):
+                continue
+            table.append(
+                [
+                    collector.get('stackArn') if collector.get('stackArn') else self._DEFAULT_COLLECTOR_VAL,
+                    collector['uuid'],
+                    collector.get('templateVersion') if collector.get('templateVersion') else self._DEFAULT_COLLECTOR_VAL,
+                    collector.get('lastUpdated') if collector.get('lastUpdated') else self._DEFAULT_COLLECTOR_VAL,
+                    collector.get('active')
+                ]
+            )
+        click.echo(tabulate(table, headers=headers, tablefmt=table_format))
+
+    @manage_errors
+    def add_collector(self, no_prompt: Optional[bool] = False) -> None:
+        """
+        Add a collector to the account. Prompts to launch browser.
+        """
+        response = self._request_wrapper.make_request_v2(
+            query=ADD_COLLECTOR_RECORD,
+            operation=EXPECTED_ADD_DC_RESPONSE_FIELD,
+        )
+        dc_id = response.data.dc.uuid
+        click.echo(f'Created collector record with ID \'{dc_id}\'')
+        if no_prompt:
+            return
+
+        prompt_connection(message=ADD_DC_PROMPT_VERBIAGE)  # exits on No
+        collection_region = click.prompt(
+            ADD_DC_REGION_PROMPT_VERBIAGE,
+            show_choices=True,
+            default=DEFAULT_COLLECTION_REGION,
+            show_default=True,
+            type=click.Choice(self._user_service.active_collection_regions)
+        )
+        self.launch_quick_create_link(dry=False, dc_id=dc_id, collection_region=collection_region)
+
+    @manage_errors
+    def launch_quick_create_link(self, dry: Optional[bool] = True, **kwargs) -> None:
         """
         Open browser with a quick create link for deploying a data collector
 
         https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cfn-console-create-stacks-quick-create-links.html
         """
-        launch_url = self._get_template_launch_url()
+        launch_url = self._get_template_launch_url(**kwargs)
         if dry:
             click.echo(launch_url)
             return
         click.launch(launch_url)
 
     @manage_errors
-    def upgrade_template(self, new_params: Optional[Dict] = None) -> None:
+    def upgrade_template(self, new_params: Optional[Dict] = None, **kwargs) -> None:
         """
         Upgrades the DC attached to this account
         """
-        collector_details = self._generate_collector_template()
+        collector_details = self._generate_collector_template(**kwargs)
         try:
             stack_arn = collector_details['stackArn']
             is_active = collector_details['active']
@@ -64,18 +116,20 @@ class CollectorManagementService:
             click.echo('Upgrade complete! Have a nice day!')
 
     @manage_errors
-    def deploy_template(self, stack_name: str, termination_protection: bool, new_params: Optional[Dict] = None) -> None:
+    def deploy_template(self, stack_name: str, termination_protection: bool, new_params: Optional[Dict] = None,
+                        **kwargs) -> None:
         """
         Deploys a template for this account
         """
         click.echo(f'Deploying \'{stack_name}\' in \'{self._collector_region}\'')
-        collector_details = self._generate_collector_template()
+        collector_details = self._generate_collector_template(**kwargs)
         is_active = collector_details['active']
         if is_active:
             complain_and_abort('Cannot deploy with an already active collector.')
 
         template_url = self._get_template_url_from_launch(collector_details['templateLaunchUrl'])
-        self._deploy(stack_name=stack_name, template_url=template_url, termination_protection=termination_protection, new_params=new_params)
+        self._deploy(stack_name=stack_name, template_url=template_url, termination_protection=termination_protection,
+                     new_params=new_params)
 
     def _upgrade(self, stack_arn: str, template_url: str, gateway_id: str, new_params: Dict) -> None:
         """
@@ -98,22 +152,29 @@ class CollectorManagementService:
                                               parameters=parameters):
             complain_and_abort('Failed to deploy. Please review CF events for details')
 
-    def _generate_collector_template(self) -> Optional[Dict]:
+    def _generate_collector_template(self, **kwargs) -> Optional[Dict]:
         """
         Generate the latest template and returns any associated dc properties (i.e. from the DataCollectorModel)
         """
+        options = {'region': self._collector_region}
+        if kwargs.get('collection_region'):
+            options['region'] = kwargs['collection_region']  # overwrite client
+
+        if kwargs.get('dc_id'):
+            options['dc_id'] = kwargs['dc_id']
+
         response = self._request_wrapper.make_request_v2(
             query=GENERATE_COLLECTOR_TEMPLATE,
             operation=EXPECTED_GENERATE_TEMPLATE_GQL_RESPONSE_FIELD,
-            variables={'region': self._collector_region}
+            variables=options
         )
         return response.data.get('dc')
 
-    def _get_template_launch_url(self) -> str:
+    def _get_template_launch_url(self, **kwargs) -> str:
         """
         Get the template launch url
         """
-        return self._generate_collector_template().get('templateLaunchUrl')
+        return self._generate_collector_template(**kwargs).get('templateLaunchUrl')
 
     @staticmethod
     def _get_template_url_from_launch(launch_url: str) -> str:
