@@ -2,8 +2,9 @@ import click
 import click_config_file
 
 import montecarlodata.settings as settings
+from montecarlodata.integrations.onboarding.bi.reports import ReportsOnboardingService
+from montecarlodata.common.commands import DISAMBIGUATE_DC_OPTIONS
 from montecarlodata.common.resources import CloudResourceService
-from montecarlodata.errors import complain_and_abort
 from montecarlodata.integrations.info.status import OnboardingStatusService
 from montecarlodata.integrations.onboarding.data_lake.events import EventsOnboardingService
 from montecarlodata.integrations.onboarding.data_lake.glue_athena import GlueAthenaOnboardingService
@@ -15,7 +16,18 @@ from montecarlodata.integrations.onboarding.fields import HIVE_MYSQL_CONNECTION_
     S3_METADATA_EVENT_TYPE, S3_QL_EVENT_TYPE, HIVE_S3_CONNECTION_TYPE
 from montecarlodata.integrations.onboarding.operations.connection_ops import ConnectionOperationsService
 from montecarlodata.integrations.onboarding.warehouse.warehouses import WarehouseOnboardingService
-from montecarlodata.tools import add_common_options, validate_json_callback
+from montecarlodata.tools import add_common_options, validate_json_callback, AdvancedOptions, \
+    convert_uuid_callback
+
+# Shared command verbiage
+METADATA_VERBIAGE = 'For metadata'
+QL_VERBIAGE = 'For query logs'
+SQL_VERBIAGE = 'For health queries'
+EVENT_VERBIAGE = 'For tracking data freshness and volume at scale. Requires s3 notifications to be configured first'
+REGION_VERBIAGE = 'If not specified the region the collector is deployed in is used'
+WAREHOUSE_VERBIAGE = 'For metadata, query logs and metrics'
+BI_VERBIAGE = 'For reports'
+PASSWORD_VERBIAGE = f'If you prefer a prompt (with hidden input) enter {settings.SHOW_PROMPT_VALUE}'
 
 # Options shared across commands
 ROLE_OPTIONS = [
@@ -35,20 +47,32 @@ DATABASE_OPTIONS = [
     click.option('--host', help='Hostname.', required=True),
     click.option('--user', help='Username with access to the database.', required=True),
     click.option('--database', help='Name of database.', required=True),
-    click.password_option('--password', help='User\'s password.', prompt='Password for user', required=True)
+    click.option('--password', help=f'User\'s password. {PASSWORD_VERBIAGE}.', required=True, cls=AdvancedOptions, prompt_if_requested=True)
 ]
 
 CONNECTION_OPTIONS = [
-    click.option('--connection-id', help='ID for the connection.', required=True, type=click.UUID)
+    click.option('--connection-id', help='ID for the connection.', required=True, type=click.UUID, callback=convert_uuid_callback)
 ]
 
-# Shared command verbiage
-METADATA_VERBIAGE = 'For metadata'
-QL_VERBIAGE = 'For query logs'
-SQL_VERBIAGE = 'For health queries'
-EVENT_VERBIAGE = 'For tracking data freshness and volume at scale. Requires s3 notifications to be configured first'
-REGION_VERBIAGE = 'If not specified the region the collector is deployed in is used'
-WAREHOUSE_VERBIAGE = 'For metadata, query logs and metrics'
+ONBOARDING_CONFIGURATION_OPTIONS = [
+    *DISAMBIGUATE_DC_OPTIONS,
+    click.option('--skip-validation', is_flag=True, help='Skip all connection tests.',
+                 cls=AdvancedOptions, mutually_exclusive_options=['validate_only']),
+    click.option('--validate-only', is_flag=True, help='Run connection tests without adding.',
+                 cls=AdvancedOptions, mutually_exclusive_options=['skip_validation']),
+    click.option('--auto-yes', is_flag=True, help='Skip any interactive approval.', default=False, show_default=True)
+]
+
+NETWORK_OPTIONS = [
+    click.option('--test-network-only', 'skip_permission_tests', is_flag=True, default=False, show_default=True,
+                 cls=AdvancedOptions, mutually_exclusive_options=['skip_validation'],
+                 help='Skip any permission tests. Only validates network connection between the collector and resource can be established.')
+]
+
+BI_OPTIONS = [
+    click.option('--verify-ssl/--no-verify-ssl', 'verify_ssl', required=False, default=True, show_default=True,
+                 help='Whether to verify the SSL connection (uncheck for self-signed certs).')
+]
 
 
 @click.group(help='Manage or integrate an asset with Monte Carlo.')
@@ -67,13 +91,13 @@ def integrations():
 @click.option('--catalog', help='Presto catalog name. For using multiple hive clusters with Presto. '
                                 'Uses \'hive\' if not specified.', required=False)
 @add_common_options(DATABASE_OPTIONS)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_hive_metastore(ctx, host, port, user, password, database, use_ssl, catalog):
+def add_hive_metastore(ctx, database, **kwargs):
     """
     Onboard a hive metastore connection (MySQL)
     """
-    HiveOnboardingService(config=ctx['config']).onboard_hive_mysql(host=host, port=port, user=user, password=password,
-                                                                   dbName=database, use_ssl=use_ssl, catalog=catalog)
+    HiveOnboardingService(config=ctx['config']).onboard_hive_mysql(dbName=database, **kwargs)
 
 
 @integrations.command(help=f'Setup a Presto SQL integration. {SQL_VERBIAGE}.')
@@ -81,29 +105,24 @@ def add_hive_metastore(ctx, host, port, user, password, database, use_ssl, catal
 @click.option('--host', help='Hostname.', required=True)
 @click.option('--port', help='HTTP port.', default=8889, type=click.INT, show_default=True)
 @click.option('--user', help='Username with access to catalog/schema.', required=False)
-@click.password_option('--password', help='User\'s password.', prompt='Password for user (enter to skip)',
-                       default='', required=False)
+@click.option('--password', help=f'User\'s password. {PASSWORD_VERBIAGE}', required=False, cls=AdvancedOptions, prompt_if_requested=True)
 @click.option('--catalog', help='Mount point to access data source.', required=True)
 @click.option('--schema', help='Schema to access.', required=True)
 @click.option('--http-scheme', help='Scheme for authentication.',
               type=click.Choice(['http', 'https'], case_sensitive=True), required=True)
 @click.option('--cert-file', help='Local SSL certificate file to upload to collector.', required=False,
-              type=click.Path(dir_okay=False, exists=True))
+              type=click.Path(dir_okay=False, exists=True), cls=AdvancedOptions, mutually_exclusive_options=['cert_s3'])
 @click.option('--cert-s3', help='Object path (key) to a certificate already uploaded to the collector.',
-              required=False)
+              required=False, cls=AdvancedOptions, mutually_exclusive_options=['cert_file'])
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_presto(ctx, host, port, user, password, catalog, schema, http_scheme, cert_file, cert_s3):
+def add_presto(ctx, password, **kwargs):
     """
     Onboard a presto sql connection
     """
     if not password:
         password = None  # make explicitly null if not set. Prompts can't be None
-    if cert_file is not None and cert_s3 is not None:
-        complain_and_abort('Can have a cert-file or cert-s3-path, but not both')
-    PrestoOnboardingService(config=ctx['config']).onboard_presto_sql(host=host, port=port, user=user, password=password,
-                                                                     catalog=catalog, schema=schema,
-                                                                     http_scheme=http_scheme, cert_file=cert_file,
-                                                                     cert_s3=cert_s3)
+    PrestoOnboardingService(config=ctx['config']).onboard_presto_sql(password=password, **kwargs)
 
 
 @integrations.command(help=f'Setup a Hive SQL integration. {SQL_VERBIAGE}.')
@@ -112,46 +131,47 @@ def add_presto(ctx, host, port, user, password, catalog, schema, http_scheme, ce
 @click.option('--database', help='Name of database.', required=False)
 @click.option('--port', help='HTTP port.', default=10000, type=click.INT, show_default=True)
 @click.option('--user', help='Username with access to hive.', required=True)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_hive(ctx, host, database, port, user):
-    HiveOnboardingService(config=ctx['config']).onboard_hive_sql(host=host, database=database, port=port, username=user)
+def add_hive(ctx, user, **kwargs):
+    HiveOnboardingService(config=ctx['config']).onboard_hive_sql(username=user, **kwargs)
 
 
 @integrations.command(help=f'Setup a Presto logs integration (S3). {QL_VERBIAGE}.')
 @click.pass_obj
 @add_common_options(S3_OPTIONS)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_presto_logs(ctx, bucket, prefix, role, external_id):
+def add_presto_logs(ctx, role, **kwargs):
     """
     Onboard a presto logs (s3) connection
     """
-    PrestoOnboardingService(config=ctx['config']).onboard_presto_s3(bucket=bucket, prefix=prefix,
-                                                                    assumable_role=role, external_id=external_id)
+    PrestoOnboardingService(config=ctx['config']).onboard_presto_s3(assumable_role=role, **kwargs)
 
 
 @integrations.command(help=f'Setup a Hive EMR logs integration (S3). {QL_VERBIAGE}.')
 @click.pass_obj
 @add_common_options(S3_OPTIONS)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_hive_logs(ctx, bucket, prefix, role, external_id):
+def add_hive_logs(ctx, role, **kwargs):
     """
     Onboard a hive emr (s3) connection
     """
-    HiveOnboardingService(config=ctx['config']).onboard_hive_s3(bucket=bucket, prefix=prefix, assumable_role=role,
-                                                                external_id=external_id)
+    HiveOnboardingService(config=ctx['config']).onboard_hive_s3(assumable_role=role, **kwargs)
 
 
 @integrations.command(help=f'Setup a Glue integration. {METADATA_VERBIAGE}.')
 @click.pass_obj
 @click.option('--region', help=f'Glue catalog region. {REGION_VERBIAGE}.', required=False)
 @add_common_options(ROLE_OPTIONS)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_glue(ctx, role, external_id, region):
+def add_glue(ctx, role, region, **kwargs):
     """
     Onboard a glue connection
     """
-    GlueAthenaOnboardingService(config=ctx['config']).onboard_glue(assumable_role=role, external_id=external_id,
-                                                                   aws_region=region)
+    GlueAthenaOnboardingService(config=ctx['config']).onboard_glue(assumable_role=role, aws_region=region, **kwargs)
 
 
 @integrations.command(help=f'Setup an Athena integration. For query logs and health queries.')
@@ -162,45 +182,45 @@ def add_glue(ctx, role, external_id, region):
               required=False)
 @click.option('--region', help=f'Athena cluster region. {REGION_VERBIAGE}.', required=False)
 @add_common_options(ROLE_OPTIONS)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_athena(ctx, catalog, workgroup, role, external_id, region):
+def add_athena(ctx, role, region, **kwargs):
     """
     Onboard an athena connection
     """
-    GlueAthenaOnboardingService(config=ctx['config']).onboard_athena(catalog=catalog, workgroup=workgroup,
-                                                                     assumable_role=role, external_id=external_id,
-                                                                     aws_region=region)
+    GlueAthenaOnboardingService(config=ctx['config']).onboard_athena(assumable_role=role, aws_region=region, **kwargs)
 
 
-@integrations.command(help=f'Setup a Spark integration in Thrift binary mode. {SQL_VERBIAGE}.')
+@integrations.command(help=f'Setup a thrift binary Spark integration. {SQL_VERBIAGE}.')
 @click.pass_obj
 @click.option('--host', help='Hostname.', required=True)
 @click.option('--database', help='Name of database.', required=True)
 @click.option('--port', help='Port.', default=10000, type=click.INT, show_default=True)
 @click.option('--user', help='Username with access to spark.', required=True)
-@click.password_option('--password', help='User\'s password.', prompt='Password for user', required=True)
+@click.option('--password', help=f'User\'s password. {PASSWORD_VERBIAGE}.', required=True,
+              cls=AdvancedOptions, prompt_if_requested=True)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_spark_binary_mode(ctx, host, database, port, user, password):
+def add_spark_binary_mode(ctx, user, **kwargs):
     """
     Onboard a spark connection, thrift binary mode
     """
-    SparkOnboardingService(config=ctx['config']).onboard_spark(SPARK_BINARY_MODE_CONFIG_TYPE,
-                                                               host=host, database=database, port=port, username=user,
-                                                               password=password)
+    SparkOnboardingService(config=ctx['config']).onboard_spark(SPARK_BINARY_MODE_CONFIG_TYPE, username=user, **kwargs)
 
 
-@integrations.command(help=f'Setup a Spark integration in Thrift HTTP mode. {SQL_VERBIAGE}.')
+@integrations.command(help=f'Setup a thrift HTTP Spark integration. {SQL_VERBIAGE}.')
 @click.pass_obj
 @click.option('--url', help='HTTP URL.', required=True)
 @click.option('--user', help='Username with access to spark.', required=True)
-@click.password_option('--password', help='User\'s password.', prompt='Password for user', required=True)
+@click.option('--password', help=f'User\'s password. {PASSWORD_VERBIAGE}.', required=True,
+              cls=AdvancedOptions, prompt_if_requested=True)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_spark_http_mode(ctx, url, user, password):
+def add_spark_http_mode(ctx, user, **kwargs):
     """
     Onboard a spark connection, thrift http mode
     """
-    SparkOnboardingService(config=ctx['config']).onboard_spark(SPARK_HTTP_MODE_CONFIG_TYPE,
-                                                               url=url, username=user, password=password)
+    SparkOnboardingService(config=ctx['config']).onboard_spark(SPARK_HTTP_MODE_CONFIG_TYPE, username=user, **kwargs)
 
 
 @integrations.command(help=f'Setup a Spark integration for Databricks. {SQL_VERBIAGE}.')
@@ -208,15 +228,15 @@ def add_spark_http_mode(ctx, url, user, password):
 @click.option('--workspace-url', help='Databricks workspace URL.', required=True)
 @click.option('--workspace-id', help='Databricks workspace ID.', required=True)
 @click.option('--cluster-id', help='Databricks cluster ID.', required=True)
-@click.password_option('--token', help='Databricks access token.', prompt='Databricks access token', required=True)
+@click.option('--token', help=f'Databricks access token. {PASSWORD_VERBIAGE}.', required=True,
+              cls=AdvancedOptions, prompt_if_requested=True)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_spark_databricks(ctx, workspace_url, workspace_id, cluster_id, token):
+def add_spark_databricks(ctx, **kwargs):
     """
     Onboard a spark connection, databricks
     """
-    SparkOnboardingService(config=ctx['config']).onboard_spark(SPARK_DATABRICKS_CONFIG_TYPE,
-                                                               workspace_url=workspace_url, workspace_id=workspace_id,
-                                                               cluster_id=cluster_id, token=token)
+    SparkOnboardingService(config=ctx['config']).onboard_spark(SPARK_DATABRICKS_CONFIG_TYPE, **kwargs)
 
 
 @integrations.command(help=f'Setup a Redshift integration. {WAREHOUSE_VERBIAGE}.')
@@ -224,14 +244,14 @@ def add_spark_databricks(ctx, workspace_url, workspace_id, cluster_id, token):
 @click.option('--port', help='HTTP port.', default=5439, type=click.INT, show_default=True)
 @click.option('--name', help='Friendly name for the warehouse.', required=True)
 @add_common_options(DATABASE_OPTIONS)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
+@add_common_options(NETWORK_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_redshift(ctx, host, port, user, password, database, name):
+def add_redshift(ctx, database, name, **kwargs):
     """
     Onboard a redshift connection
     """
-    WarehouseOnboardingService(config=ctx['config']).onboard_redshift(host=host, port=port, user=user,
-                                                                      password=password, dbName=database,
-                                                                      warehouseName=name)
+    WarehouseOnboardingService(config=ctx['config']).onboard_redshift(dbName=database, warehouseName=name, **kwargs)
 
 
 @integrations.command(help=f'Setup a Snowflake integration. {WAREHOUSE_VERBIAGE}.')
@@ -239,30 +259,32 @@ def add_redshift(ctx, host, port, user, password, database, name):
 @click.option('--user', help='User with access to snowflake.', required=True)
 @click.option('--account', help='Snowflake account name.', required=True)
 @click.option('--warehouse', help='Name of the warehouse for the user.', required=True)
-@click.password_option('--password', help='User\'s password.', prompt='Password for user', required=True)
+@click.option('--password', help=f'User\'s password. {PASSWORD_VERBIAGE}.', required=True,
+              cls=AdvancedOptions, prompt_if_requested=True)
 @click.option('--name', help='Friendly name for the warehouse.', required=True)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_snowflake(ctx, user, account, warehouse, password, name):
+def add_snowflake(ctx, name, **kwargs):
     """
     Onboard a snowflake connection
     """
-    WarehouseOnboardingService(config=ctx['config']).onboard_snowflake(account=account, password=password, user=user,
-                                                                       warehouse=warehouse, warehouseName=name)
+    WarehouseOnboardingService(config=ctx['config']).onboard_snowflake(warehouseName=name, **kwargs)
 
 
 @integrations.command(help=f'Setup a BigQuery integration. {WAREHOUSE_VERBIAGE}.')
 @click.pass_obj
 @click.option('--key-file', help='JSON Key file.', type=click.Path(exists=True), required=True)
 @click.option('--name', help='Friendly name for the warehouse.', required=True)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_bigquery(ctx, key_file, name):
+def add_bigquery(ctx, key_file, name, **kwargs):
     """
     Onboard a BigQuery connection
     """
-    WarehouseOnboardingService(config=ctx['config']).onboard_bq(ServiceFile=key_file, warehouseName=name)
+    WarehouseOnboardingService(config=ctx['config']).onboard_bq(ServiceFile=key_file, warehouseName=name, **kwargs)
 
 
-@integrations.command(help=f'Toggle S3 metadata events for a Hive/Presto lake. {EVENT_VERBIAGE}.')
+@integrations.command(help=f'Toggle S3 metadata events for Hive/Presto. {EVENT_VERBIAGE}.')
 @click.pass_obj
 @add_common_options(EVENT_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
@@ -275,7 +297,7 @@ def toggle_hive_metadata_events(ctx, toggle):
                                                                              event_type=S3_METADATA_EVENT_TYPE)
 
 
-@integrations.command(help=f'Toggle S3 metadata events for a Glue/Athena lake. {EVENT_VERBIAGE}.')
+@integrations.command(help=f'Toggle S3 metadata events for Glue/Athena. {EVENT_VERBIAGE}.')
 @click.pass_obj
 @add_common_options(EVENT_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
@@ -307,7 +329,60 @@ def toggle_ql_events(ctx, toggle, role, external_id, type):
                                                                              format_type=type)
 
 
-@integrations.command(help=f'List all active integrations.', name='list')
+@integrations.command(help=f'Setup a Tableau integration. {BI_VERBIAGE}.')
+@click.pass_obj
+@click.option('--token-name', help='Name for the personal access token.', cls=AdvancedOptions,
+              mutually_exclusive_options=['password', 'username'], required_with_options=['token_value'],
+              at_least_one_set=['password', 'username', 'token_name', 'token_value'])
+@click.option('--token-value', help=f'Value for the personal access token. {PASSWORD_VERBIAGE}.', cls=AdvancedOptions,
+              mutually_exclusive_options=['password', 'username'], required_with_options=['token_name'],
+              prompt_if_requested=True)
+@click.option('--password', help=f'Password for the service account. {PASSWORD_VERBIAGE}.', cls=AdvancedOptions,
+              mutually_exclusive_options=['token_name', 'token_value'], required_with_options=['user'],
+              prompt_if_requested=True)
+@click.option('--user', help='Username for the service account.', cls=AdvancedOptions,
+              mutually_exclusive_options=['token_name', 'token_value'], required_with_options=['password'])
+@click.option('--site-name', help='The Tableau site name.', required=True)
+@click.option('--server-name', help='The Tableau server name.', required=True)
+@add_common_options(BI_OPTIONS)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def add_tableau(ctx, user, **kwargs):
+    """
+    Onboard a tableau connection
+    """
+    ReportsOnboardingService(config=ctx['config']).onboard_tableau(username=user, **kwargs)
+
+
+@integrations.command(help=f'Setup a Looker metadata integration. {BI_VERBIAGE}.')
+@click.pass_obj
+@click.option('--host-url', 'base_url', help='Looker host url.', required=True)
+@click.option('--client-id', help='Looker client id.', required=True)
+@click.option('--client-secret', help=f'Looker client secret (API key). {PASSWORD_VERBIAGE}.',
+              required=True, cls=AdvancedOptions, prompt_if_requested=True)
+@add_common_options(BI_OPTIONS)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
+def add_looker(ctx, **kwargs):
+    """
+    Onboard a looker metadata connection
+    """
+    ReportsOnboardingService(config=ctx['config']).onboard_looker_metadata(**kwargs)
+
+
+@integrations.command(help=f'Setup a Looker ML (git) integration. {BI_VERBIAGE}.')
+@click.pass_obj
+@click.argument('ssh-key', required=True, type=click.Path(dir_okay=False, exists=True))
+@click.option('--repo-url', help='Repository URL as ssh://[user@]server/project.git or the shorter '
+                                 'form [user@]server:project.git.', required=True)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
+def add_looker_git(ctx, **kwargs):
+    """
+    Onboard a looker metadata connection
+    """
+    ReportsOnboardingService(config=ctx['config']).onboard_looker_git(**kwargs)
+
+
+@integrations.command(help=f'List all active connections.', name='list')
 @click.pass_obj
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def display_integrations(ctx):
@@ -317,7 +392,7 @@ def display_integrations(ctx):
     OnboardingStatusService(config=ctx['config']).display_integrations()
 
 
-@integrations.command(help='Create an IAM role from the provided policy FILE. '
+@integrations.command(help='Create an IAM role from a policy FILE. '
                            'The returned role ARN and external id should be used for adding lake assets.')
 @click.pass_obj
 @click.argument('file', type=click.Path(dir_okay=False, exists=True))
@@ -331,7 +406,7 @@ def create_role(ctx, file, aws_profile):
     CloudResourceService(config=ctx['config'], aws_profile_override=aws_profile).create_role(path_to_policy_doc=file)
 
 
-@integrations.command(help=f'Update credentials for a connection.')
+@integrations.command(help=f'Update credentials for a connection.', name='update')
 @click.pass_obj
 @add_common_options(CONNECTION_OPTIONS)
 @click.option('--changes', help="""
@@ -350,14 +425,24 @@ def update_credentials(ctx, connection_id, changes, skip_validation):
                                                                          should_validate=not skip_validation)
 
 
-@integrations.command(help=f'Remove a connection. Deletes any associated jobs, monitors, etc.')
+@integrations.command(help=f'Remove an existing connection. Deletes any associated jobs, monitors, etc.', name='remove')
 @click.pass_obj
 @add_common_options(CONNECTION_OPTIONS)
 @click.option('--no-prompt', help='Don\'t ask for confirmation.', default=False, show_default=True, is_flag=True)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def remove_connection(ctx, connection_id, no_prompt):
+def remove_connection(ctx, **kwargs):
     """
     Remove connection by ID
     """
-    ConnectionOperationsService(config=ctx['config']).remove_connection(connection_id=connection_id,
-                                                                        no_prompt=no_prompt)
+    ConnectionOperationsService(config=ctx['config']).remove_connection(**kwargs)
+
+
+@integrations.command(help=f'Retest an existing connection.', name='test')
+@click.pass_obj
+@add_common_options(CONNECTION_OPTIONS)
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def echo_test_existing(ctx, **kwargs):
+    """
+    Tests an existing connection and echos results in pretty JSON.
+    """
+    ConnectionOperationsService(config=ctx['config']).echo_test_existing(**kwargs)
