@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, List, Dict
 
 import click
 from tabulate import tabulate
@@ -28,14 +28,19 @@ class OnboardingStatusService:
         ╘══════════════════╧══════════════════════════════════════╧══════════════════════════════════╛
         """
         table = [self._INTEGRATION_FRIENDLY_HEADERS]
-        for warehouse in self._user_service.warehouses or [{}]:
-            connections = warehouse.get('connections')
-            for connection in connections or []:
-                table.append(
-                    [
-                        GQL_TO_FRIENDLY_CONNECTION_MAP.get(normalize_gql(connection['type']), connection['type']),
-                        connection['uuid'],
-                        connection['createdOn']
-                    ]
-                )  # order by the friendly headers, defaulting to gql response if not found
+        for integration in (self._user_service.warehouses or [{}]) + (self._user_service.bi_containers or [{}]):
+            table += self._build_table_record(connections=integration.get('connections'))
         click.echo(tabulate(table, headers=headers, tablefmt=table_format))
+
+    @staticmethod
+    def _build_table_record(connections: List[Dict]) -> List[List[str]]:
+        table = []
+        for connection in connections or []:
+            table.append(
+                [
+                    GQL_TO_FRIENDLY_CONNECTION_MAP.get(normalize_gql(connection['type']), connection['type']),
+                    connection['uuid'],
+                    connection['createdOn']
+                ]
+            )  # order by the friendly headers, defaulting to gql response if not found
+        return table
