@@ -1,30 +1,25 @@
 import json
 import os
-from dataclasses import dataclass
-from tabulate import tabulate
-from typing import Optional, Dict, List, Tuple
+from typing import Optional, Dict, List
 
 import click
+from tabulate import tabulate
 
+from montecarlodata.common.data import ConnectionOptions, ValidationResult, OnboardingConfiguration
 from montecarlodata.common.common import normalize_gql
 from montecarlodata.common.user import UserService
 from montecarlodata.config import Config
-from montecarlodata.errors import complain_and_abort
+from montecarlodata.errors import complain_and_abort, prompt_connection
 from montecarlodata.integrations.onboarding.fields import S3_CERT_MECHANISM, GQL_TO_FRIENDLY_CONNECTION_MAP, \
-    DATA_LAKE_WAREHOUSE_TYPE
+    DATA_LAKE_WAREHOUSE_TYPE, EXPECTED_ADD_CONNECTION_RESPONSE_FIELD, CONFIRM_CONNECTION_VERBIAGE, VALIDATIONS_FAILED_VERBIAGE, \
+    SKIP_ADD_CONNECTION_VERBIAGE, CONNECTION_TEST_SUCCESS_VERBIAGE, CONNECTION_TEST_FAILED_VERBIAGE, \
+    ADD_CONNECTION_FAILED_VERBIAGE, ADD_CONNECTION_SUCCESS_VERBIAGE
 from montecarlodata.queries.onboarding import ADD_CONNECTION_MUTATION
 from montecarlodata.utils import GqlWrapper, AwsClientWrapper
 
 
-@dataclass
-class ValidationResult:
-    has_warnings: bool
-    credentials_key: str
-
-
 class BaseOnboardingService:
-
-    _VALIDATION_STATUS_HEADERS = ["Validation", "Result", "Details"]
+    _VALIDATION_STATUS_HEADERS = ['Validation', 'Result', 'Details']
     _VALIDATION_PASSED = 'Passed'
     _VALIDATION_FAILED = 'Failed'
 
@@ -40,34 +35,28 @@ class BaseOnboardingService:
         self._aws_wrapper = aws_wrapper or AwsClientWrapper(profile_name=config.aws_profile,
                                                             region_name=config.aws_region)
 
-    def onboard(self, validation_query: str, validation_response: str, connection_type: str,
-                job_types: Optional[List[str]] = None, job_limits: Optional[Dict] = None, **kwargs):
+    def onboard(self, **kwargs):
         """
         Convenience wrapper to validate and add a connection.
         """
-        warehouse_name = kwargs.pop('warehouseName', None)
-        warehouse_type = kwargs.pop('warehouseType', DATA_LAKE_WAREHOUSE_TYPE)
+        onboarding_config = OnboardingConfiguration(**kwargs)  # not passed as arg to avoid having to change all clients
+        onboarding_config.connection_options = self._build_connection_options(**onboarding_config.connection_options)
 
-        # TODO REMOVE - temp property lookup. Will error out if no active collectors are found.
-        #  The User service and collector handling will be updated as part of multi-collector support, so this will
-        #  no longer be done / necessary.
-        self._user_service.active_collector
+        onboarding_config.warehouse_name = onboarding_config.connection_options.monolith_base_payload.pop('warehouseName', None)
+        onboarding_config.warehouse_type = onboarding_config.connection_options.monolith_base_payload.pop('warehouseType', DATA_LAKE_WAREHOUSE_TYPE)
 
         result = self._validate_connection(
-            query=validation_query,
-            response_field=validation_response,
-            **kwargs)
+            query=onboarding_config.validation_query,
+            response_field=onboarding_config.validation_response,
+            **onboarding_config.connection_options.monolith_base_payload
+        )
 
-        if result.has_warnings:
-            click.confirm('Some validations failed. Would you like to create the connection anyway?', abort=True)
-
-        self._add_connection(
-            temp_path=result.credentials_key,
-            connection_type=connection_type,
-            job_types=job_types,
-            job_limits=job_limits,
-            warehouse_type=warehouse_type,
-            warehouse_name=warehouse_name)
+        if not onboarding_config.connection_options.validate_only:
+            prompt = VALIDATIONS_FAILED_VERBIAGE if result.has_warnings else CONFIRM_CONNECTION_VERBIAGE
+            prompt_connection(message=prompt, skip_prompt=onboarding_config.connection_options.auto_yes)
+            self._add_connection(temp_path=result.credentials_key, onboarding_config=onboarding_config)
+        else:
+            click.echo(SKIP_ADD_CONNECTION_VERBIAGE)
 
     def handle_cert(self, cert_prefix: str, options: Dict) -> None:
         """
@@ -103,13 +92,13 @@ class BaseOnboardingService:
         warnings = response.data.get('warnings')
 
         if temp_path is not None:
-            click.echo(f'Connection successful!{summary}')
+            click.echo(f'{CONNECTION_TEST_SUCCESS_VERBIAGE}{summary}')
             return ValidationResult(
                 has_warnings=warnings is not None and len(warnings) > 0,
                 credentials_key=temp_path
             )
 
-        complain_and_abort(f'Connection failed!{summary}')
+        complain_and_abort(f'{CONNECTION_TEST_FAILED_VERBIAGE}{summary}')
 
     def _build_validation_summary(self, response: Dict, table_format: Optional[str] = 'fancy_grid') -> str:
         data = []
@@ -135,31 +124,35 @@ class BaseOnboardingService:
         # do not provide a summary if no detailed response is available
         return ''
 
-    def _add_connection(self, temp_path: str, connection_type: str, job_types: Optional[List[str]] = None,
-                        warehouse_type: Optional[str] = None, job_limits: Optional[Dict] = None,
-                        warehouse_name: Optional[str] = None) -> bool:
+    def _add_connection(self, temp_path: str, onboarding_config: OnboardingConfiguration) -> bool:
         """
         Add connection and setup any associated jobs
         """
-        warehouse_type = warehouse_type or DATA_LAKE_WAREHOUSE_TYPE  # default to data-lake
-        connection_request = {'key': temp_path, 'connectionType': connection_type}
+        warehouse_type = onboarding_config.warehouse_type or DATA_LAKE_WAREHOUSE_TYPE  # default to data-lake
+        connection_request = {'key': temp_path, 'connectionType': onboarding_config.connection_type}
         connection_request.update(self._disambiguate_warehouses(warehouse_type))
 
         # Set optional properties
-        if warehouse_name:
-            connection_request['name'] = warehouse_name
-        if job_types:
-            connection_request['jobTypes'] = job_types
-        if job_limits:
-            connection_request['jobLimits'] = json.dumps(job_limits)
+        if onboarding_config.warehouse_name:
+            connection_request['name'] = onboarding_config.warehouse_name
+        if onboarding_config.job_types:
+            connection_request['jobTypes'] = onboarding_config.job_types
+        if onboarding_config.job_limits:
+            connection_request['jobLimits'] = json.dumps(onboarding_config.job_limits)
+        if onboarding_config.connection_options and onboarding_config.connection_options.dc_id:
+            connection_request['dcId'] = onboarding_config.connection_options.dc_id
 
-        response = self._request_wrapper.make_request(query=ADD_CONNECTION_MUTATION, variables=connection_request)
-        connection_id = response.get('addConnection', {}).get('connection', {}).get('uuid')
+        response = self._request_wrapper.make_request_v2(
+            query=onboarding_config.connection_query or ADD_CONNECTION_MUTATION,
+            operation=onboarding_config.connection_response or EXPECTED_ADD_CONNECTION_RESPONSE_FIELD,
+            variables=connection_request,
+        )
+        connection_id = response.data.get('connection', {}).get('uuid')
         if connection_id is not None:
-            click.echo(f"Success! Added connection for "
-                       f"{GQL_TO_FRIENDLY_CONNECTION_MAP.get(connection_type, connection_type.capitalize())}.")
+            click.echo(f"{ADD_CONNECTION_SUCCESS_VERBIAGE}"
+                       f"{GQL_TO_FRIENDLY_CONNECTION_MAP.get(onboarding_config.connection_type, onboarding_config.connection_type.capitalize())}.")
             return True
-        complain_and_abort('Failed to add connection!')
+        complain_and_abort(ADD_CONNECTION_FAILED_VERBIAGE)
 
     def _disambiguate_warehouses(self, warehouse_type: str) -> Dict:
         """
@@ -184,3 +177,14 @@ class BaseOnboardingService:
         for output in self._dc_outputs:
             if output['OutputKey'] == prop:
                 return output['OutputValue']
+
+    @staticmethod
+    def _build_connection_options(**kwargs) -> ConnectionOptions:
+        """
+        Create connection options from arguments
+        """
+        connection_options = ConnectionOptions(**kwargs)
+
+        if connection_options.monolith_connection_payload:
+            connection_options.monolith_base_payload['connectionOptions'] = connection_options.monolith_connection_payload
+        return connection_options
