@@ -43,8 +43,11 @@ HELP_FLAG = '--help'
 # Option file flag
 OPTION_FILE_FLAG = '--option-file'
 
+# Value (if entered) to show prompt with hidden input
+SHOW_PROMPT_VALUE = '-1'
 
 """Monitors as code configs"""
+
 DEFAULT_MONTECARLO_MONITOR_CONFIG_VERSION = 1
 
 PROJECT_CONFIG_FILENAME = 'montecarlo.yml'
@@ -61,4 +64,3 @@ DEFAULT_EXCLUDE_PATTERNS = [
     'dbt_project.yml',
     'montecarlo.yml'
 ]
-
