@@ -4,6 +4,7 @@ from typing import Dict, Optional, List, Iterable
 
 import boto3
 import requests
+from box import Box
 from retry import retry
 
 import montecarlodata.settings as settings
@@ -38,8 +39,10 @@ class GqlWrapper(Wrapper):
         """
         Make a GraphQl request to the MCD API and parse out the results into data and errors. Aborts on error if set.
         """
-        response = self._make_request(query=query, variables=self.convert_snakes_to_camels(variables))
-        parsed_response = MonolithResponse(data=response.get('data', {}).get(operation), errors=response.get('errors'))
+        response = self._make_request(query=query, variables=self.convert_snakes_to_camels(variables) if variables else variables)
+        data = response.get('data', {}).get(operation)
+
+        parsed_response = MonolithResponse(data=Box(data) if data else data, errors=response.get('errors'))
 
         if self._abort_on_error:
             abort_on_gql_errors(parsed_response)
